==> pw-iso20022-SRU2024-9.5.0-sources.jar: com/prowidesoftware/swift/model/mx/dic/CorporateActionNarrative62.java <==

package com.prowidesoftware.swift.model.mx.dic;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Provides additional information such as the taxation conditions.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CorporateActionNarrative62", propOrder = {
    "addtlTxt",
    "nrrtvVrsn",
    "infConds",
    "infToCmplyWth",
    "taxtnConds",
    "dsclmr",
    "ptyCtctNrrtv",
    "regnDtls",
    "bsktOrIndxInf",
    "certfctnBrkdwn",
    "prcgTxtForNxtIntrmy"
})
public class CorporateActionNarrative62 {

    @XmlElement(name = "AddtlTxt")
    protected UpdatedAdditionalInformation23 addtlTxt;
    @XmlElement(name = "NrrtvVrsn")
    protected UpdatedAdditionalInformation23 nrrtvVrsn;
    @XmlElement(name = "InfConds")
    protected UpdatedAdditionalInformation23 infConds;
    @XmlElement(name = "InfToCmplyWth")
    protected UpdatedAdditionalInformation23 infToCmplyWth;
    @XmlElement(name = "TaxtnConds")
    protected UpdatedAdditionalInformation23 taxtnConds;
    @XmlElement(name = "Dsclmr")
    protected UpdatedAdditionalInformation23 dsclmr;
    @XmlElement(name = "PtyCtctNrrtv")
    protected UpdatedAdditionalInformation23 ptyCtctNrrtv;
    @XmlElement(name = "RegnDtls")
    protected UpdatedAdditionalInformation23 regnDtls;
    @XmlElement(name = "BsktOrIndxInf")
    protected UpdatedAdditionalInformation23 bsktOrIndxInf;
    @XmlElement(name = "CertfctnBrkdwn")
    protected UpdatedAdditionalInformation23 certfctnBrkdwn;
    @XmlElement(name = "PrcgTxtForNxtIntrmy")
    protected UpdatedAdditionalInformation23 prcgTxtForNxtIntrmy;

    /**
     * Gets the value of the addtlTxt property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public UpdatedAdditionalInformation23 getAddtlTxt() {
        return addtlTxt;
    }

    /**
     * Sets the value of the addtlTxt property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public CorporateActionNarrative62 setAddtlTxt(UpdatedAdditionalInformation23 value) {
        this.addtlTxt = value;
        return this;
    }

    /**
     * Gets the value of the nrrtvVrsn property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public UpdatedAdditionalInformation23 getNrrtvVrsn() {
        return nrrtvVrsn;
    }

    /**
     * Sets the value of the nrrtvVrsn property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public CorporateActionNarrative62 setNrrtvVrsn(UpdatedAdditionalInformation23 value) {
        this.nrrtvVrsn = value;
        return this;
    }

    /**
     * Gets the value of the infConds property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public UpdatedAdditionalInformation23 getInfConds() {
        return infConds;
    }

    /**
     * Sets the value of the infConds property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public CorporateActionNarrative62 setInfConds(UpdatedAdditionalInformation23 value) {
        this.infConds = value;
        return this;
    }

    /**
     * Gets the value of the infToCmplyWth property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public UpdatedAdditionalInformation23 getInfToCmplyWth() {
        return infToCmplyWth;
    }

    /**
     * Sets the value of the infToCmplyWth property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public CorporateActionNarrative62 setInfToCmplyWth(UpdatedAdditionalInformation23 value) {
        this.infToCmplyWth = value;
        return this;
    }

    /**
     * Gets the value of the taxtnConds property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public UpdatedAdditionalInformation23 getTaxtnConds() {
        return taxtnConds;
    }

    /**
     * Sets the value of the taxtnConds property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public CorporateActionNarrative62 setTaxtnConds(UpdatedAdditionalInformation23 value) {
        this.taxtnConds = value;
        return this;
    }

    /**
     * Gets the value of the dsclmr property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public UpdatedAdditionalInformation23 getDsclmr() {
        return dsclmr;
    }

    /**
     * Sets the value of the dsclmr property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public CorporateActionNarrative62 setDsclmr(UpdatedAdditionalInformation23 value) {
        this.dsclmr = value;
        return this;
    }

    /**
     * Gets the value of the ptyCtctNrrtv property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public UpdatedAdditionalInformation23 getPtyCtctNrrtv() {
        return ptyCtctNrrtv;
    }

    /**
     * Sets the value of the ptyCtctNrrtv property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public CorporateActionNarrative62 setPtyCtctNrrtv(UpdatedAdditionalInformation23 value) {
        this.ptyCtctNrrtv = value;
        return this;
    }

    /**
     * Gets the value of the regnDtls property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public UpdatedAdditionalInformation23 getRegnDtls() {
        return regnDtls;
    }

    /**
     * Sets the value of the regnDtls property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public CorporateActionNarrative62 setRegnDtls(UpdatedAdditionalInformation23 value) {
        this.regnDtls = value;
        return this;
    }

    /**
     * Gets the value of the bsktOrIndxInf property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public UpdatedAdditionalInformation23 getBsktOrIndxInf() {
        return bsktOrIndxInf;
    }

    /**
     * Sets the value of the bsktOrIndxInf property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public CorporateActionNarrative62 setBsktOrIndxInf(UpdatedAdditionalInformation23 value) {
        this.bsktOrIndxInf = value;
        return this;
    }

    /**
     * Gets the value of the certfctnBrkdwn property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public UpdatedAdditionalInformation23 getCertfctnBrkdwn() {
        return certfctnBrkdwn;
    }

    /**
     * Sets the value of the certfctnBrkdwn property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public CorporateActionNarrative62 setCertfctnBrkdwn(UpdatedAdditionalInformation23 value) {
        this.certfctnBrkdwn = value;
        return this;
    }

    /**
     * Gets the value of the prcgTxtForNxtIntrmy property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public UpdatedAdditionalInformation23 getPrcgTxtForNxtIntrmy() {
        return prcgTxtForNxtIntrmy;
    }

    /**
     * Sets the value of the prcgTxtForNxtIntrmy property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public CorporateActionNarrative62 setPrcgTxtForNxtIntrmy(UpdatedAdditionalInformation23 value) {
        this.prcgTxtForNxtIntrmy = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}

==> pw-iso20022-SRU2024-10.2.9-sources.jar: com/prowidesoftware/swift/model/mx/dic/CorporateActionNarrative62.java <==

package com.prowidesoftware.swift.model.mx.dic;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Provides additional information such as the taxation conditions.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CorporateActionNarrative62", propOrder = {
    "addtlTxt",
    "nrrtvVrsn",
    "infConds",
    "infToCmplyWth",
    "taxtnConds",
    "dsclmr",
    "ptyCtctNrrtv",
    "regnDtls",
    "bsktOrIndxInf",
    "certfctnBrkdwn",
    "prcgTxtForNxtIntrmy"
})
public class CorporateActionNarrative62 {

    @XmlElement(name = "AddtlTxt")
    protected UpdatedAdditionalInformation23 addtlTxt;
    @XmlElement(name = "NrrtvVrsn")
    protected UpdatedAdditionalInformation23 nrrtvVrsn;
    @XmlElement(name = "InfConds")
    protected UpdatedAdditionalInformation23 infConds;
    @XmlElement(name = "InfToCmplyWth")
    protected UpdatedAdditionalInformation23 infToCmplyWth;
    @XmlElement(name = "TaxtnConds")
    protected UpdatedAdditionalInformation23 taxtnConds;
    @XmlElement(name = "Dsclmr")
    protected UpdatedAdditionalInformation23 dsclmr;
    @XmlElement(name = "PtyCtctNrrtv")
    protected UpdatedAdditionalInformation23 ptyCtctNrrtv;
    @XmlElement(name = "RegnDtls")
    protected UpdatedAdditionalInformation23 regnDtls;
    @XmlElement(name = "BsktOrIndxInf")
    protected UpdatedAdditionalInformation23 bsktOrIndxInf;
    @XmlElement(name = "CertfctnBrkdwn")
    protected UpdatedAdditionalInformation23 certfctnBrkdwn;
    @XmlElement(name = "PrcgTxtForNxtIntrmy")
    protected UpdatedAdditionalInformation23 prcgTxtForNxtIntrmy;

    /**
     * Gets the value of the addtlTxt property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public UpdatedAdditionalInformation23 getAddtlTxt() {
        return addtlTxt;
    }

    /**
     * Sets the value of the addtlTxt property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public CorporateActionNarrative62 setAddtlTxt(UpdatedAdditionalInformation23 value) {
        this.addtlTxt = value;
        return this;
    }

    /**
     * Gets the value of the nrrtvVrsn property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public UpdatedAdditionalInformation23 getNrrtvVrsn() {
        return nrrtvVrsn;
    }

    /**
     * Sets the value of the nrrtvVrsn property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public CorporateActionNarrative62 setNrrtvVrsn(UpdatedAdditionalInformation23 value) {
        this.nrrtvVrsn = value;
        return this;
    }

    /**
     * Gets the value of the infConds property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public UpdatedAdditionalInformation23 getInfConds() {
        return infConds;
    }

    /**
     * Sets the value of the infConds property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public CorporateActionNarrative62 setInfConds(UpdatedAdditionalInformation23 value) {
        this.infConds = value;
        return this;
    }

    /**
     * Gets the value of the infToCmplyWth property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public UpdatedAdditionalInformation23 getInfToCmplyWth() {
        return infToCmplyWth;
    }

    /**
     * Sets the value of the infToCmplyWth property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public CorporateActionNarrative62 setInfToCmplyWth(UpdatedAdditionalInformation23 value) {
        this.infToCmplyWth = value;
        return this;
    }

    /**
     * Gets the value of the taxtnConds property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public UpdatedAdditionalInformation23 getTaxtnConds() {
        return taxtnConds;
    }

    /**
     * Sets the value of the taxtnConds property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public CorporateActionNarrative62 setTaxtnConds(UpdatedAdditionalInformation23 value) {
        this.taxtnConds = value;
        return this;
    }

    /**
     * Gets the value of the dsclmr property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public UpdatedAdditionalInformation23 getDsclmr() {
        return dsclmr;
    }

    /**
     * Sets the value of the dsclmr property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public CorporateActionNarrative62 setDsclmr(UpdatedAdditionalInformation23 value) {
        this.dsclmr = value;
        return this;
    }

    /**
     * Gets the value of the ptyCtctNrrtv property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public UpdatedAdditionalInformation23 getPtyCtctNrrtv() {
        return ptyCtctNrrtv;
    }

    /**
     * Sets the value of the ptyCtctNrrtv property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public CorporateActionNarrative62 setPtyCtctNrrtv(UpdatedAdditionalInformation23 value) {
        this.ptyCtctNrrtv = value;
        return this;
    }

    /**
     * Gets the value of the regnDtls property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public UpdatedAdditionalInformation23 getRegnDtls() {
        return regnDtls;
    }

    /**
     * Sets the value of the regnDtls property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public CorporateActionNarrative62 setRegnDtls(UpdatedAdditionalInformation23 value) {
        this.regnDtls = value;
        return this;
    }

    /**
     * Gets the value of the bsktOrIndxInf property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public UpdatedAdditionalInformation23 getBsktOrIndxInf() {
        return bsktOrIndxInf;
    }

    /**
     * Sets the value of the bsktOrIndxInf property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public CorporateActionNarrative62 setBsktOrIndxInf(UpdatedAdditionalInformation23 value) {
        this.bsktOrIndxInf = value;
        return this;
    }

    /**
     * Gets the value of the certfctnBrkdwn property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public UpdatedAdditionalInformation23 getCertfctnBrkdwn() {
        return certfctnBrkdwn;
    }

    /**
     * Sets the value of the certfctnBrkdwn property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public CorporateActionNarrative62 setCertfctnBrkdwn(UpdatedAdditionalInformation23 value) {
        this.certfctnBrkdwn = value;
        return this;
    }

    /**
     * Gets the value of the prcgTxtForNxtIntrmy property.
     * 
     * @return
     *     possible object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public UpdatedAdditionalInformation23 getPrcgTxtForNxtIntrmy() {
        return prcgTxtForNxtIntrmy;
    }

    /**
     * Sets the value of the prcgTxtForNxtIntrmy property.
     * 
     * @param value
     *     allowed object is
     *     {@link UpdatedAdditionalInformation23 }
     *     
     */
    public CorporateActionNarrative62 setPrcgTxtForNxtIntrmy(UpdatedAdditionalInformation23 value) {
        this.prcgTxtForNxtIntrmy = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}
